@@ -47,8 +47,10 @@ SEXP R_similarity_ngCMatrix(SEXP x, SEXP y, SEXP R_method, SEXP R_weight) {
 
     PROTECT(r = NEW_OBJECT(MAKE_CLASS((m) ? "dgCMatrix" : "dsCMatrix")));
 
-    if (!m)
-	setAttrib(r, install("uplo"), mkString("L"));
+    if (!m) {
+	setAttrib(r, install("uplo"), PROTECT(mkString("L")));
+	UNPROTECT(1);
+    }
 
     // FIXME can we bound the initial memory allocation
     //       to less than full storage representation?
@@ -60,9 +62,10 @@ SEXP R_similarity_ngCMatrix(SEXP x, SEXP y, SEXP R_method, SEXP R_weight) {
 	a = 1;
     }
 
-    setAttrib(r, install("p"), (pr = allocVector(INTSXP, LENGTH(py))));
-    setAttrib(r, install("i"), (ir = allocVector(INTSXP, n)));
-    setAttrib(r, install("x"), (xr = allocVector(REALSXP, n)));
+    setAttrib(r, install("p"), PROTECT(pr = allocVector(INTSXP, LENGTH(py))));
+    setAttrib(r, install("i"), PROTECT(ir = allocVector(INTSXP, n)));
+    setAttrib(r, install("x"), PROTECT(xr = allocVector(REALSXP, n)));
+    UNPROTECT(3);
 
     // precompute
     zx = REAL(PROTECT(allocVector(REALSXP, LENGTH(px))));
@@ -89,16 +92,16 @@ SEXP R_similarity_ngCMatrix(SEXP x, SEXP y, SEXP R_method, SEXP R_weight) {
 	    SEXP t;
 
 	    PROTECT(t = ir);
-	    setAttrib(r, install("i"), (ir = allocVector(INTSXP, LENGTH(ir) * 2)));
+	    setAttrib(r, install("i"), PROTECT(ir = allocVector(INTSXP, LENGTH(ir) * 2)));
 	    memcpy(INTEGER(ir), INTEGER(t), sizeof(int) * n);
 
-	    UNPROTECT(1);
+	    UNPROTECT(2);
 
 	    PROTECT(t = xr);
-	    setAttrib(r, install("x"), (xr = allocVector(REALSXP, LENGTH(ir))));
+	    setAttrib(r, install("x"), PROTECT(xr = allocVector(REALSXP, LENGTH(ir))));
 	    memcpy(REAL(xr), REAL(t), sizeof(double) * n);
 
-	    UNPROTECT(1);
+	    UNPROTECT(2);
 	}
 
 	ly = INTEGER(py)[j];
@@ -176,16 +179,16 @@ SEXP R_similarity_ngCMatrix(SEXP x, SEXP y, SEXP R_method, SEXP R_weight) {
 
     if (n < LENGTH(ir)) {
 	PROTECT(ix = ir);
-	setAttrib(r, install("i"), (ir = allocVector(INTSXP, n)));
+	setAttrib(r, install("i"), PROTECT(ir = allocVector(INTSXP, n)));
 	memcpy(INTEGER(ir), INTEGER(ix), sizeof(int) * n);
 
-	UNPROTECT(1);
+	UNPROTECT(2);
 
 	PROTECT(ix = xr);
-	setAttrib(r, install("x"), (xr = allocVector(REALSXP, n)));
+	setAttrib(r, install("x"), PROTECT(xr = allocVector(REALSXP, n)));
 	memcpy(REAL(xr), REAL(ix), sizeof(double) * n);
 
-	UNPROTECT(1);
+	UNPROTECT(2);
     }
 
     ix = getAttrib(r, install("Dim"));
